==> haskell-ipynb-0.1.0.1-191-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.1.0.1
visibility:           public
id:                   ipynb-0.1.0.1-6xtSAAwYcmb84KVDYNyYjQ
key:                  ipynb-0.1.0.1-6xtSAAwYcmb84KVDYNyYjQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  f5992367aec7b5be284696c246744dc0
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-8.10.4/site-local/ipynb-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ipynb-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/ipynb-0.1.0.1
hs-libraries:         HSipynb-0.1.0.1-6xtSAAwYcmb84KVDYNyYjQ
depends:
    aeson-1.5.6.0-GONgLS6yTtf17t9dlS8fIx base-4.14.1.0
    base64-bytestring-1.2.0.1-3dX39isVKnJ9vuK9OH6kQ
    bytestring-0.10.12.0 containers-0.6.2.1 text-1.2.4.1
    unordered-containers-0.2.13.0-GpKX90RmBie7xFEkTgVtxL

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ipynb-0.1.0.1-192-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ipynb.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ipynb
version:              0.1.0.1
visibility:           public
id:                   ipynb-0.1.0.1-3DGBPS2DK367lmIfmMkRLO
key:                  ipynb-0.1.0.1-3DGBPS2DK367lmIfmMkRLO
license:              BSD-3-Clause
copyright:            Copyright (C) 2019 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
synopsis:             Data structure for working with Jupyter notebooks (ipynb).
description:
    ipynb defines a data structure for representing Jupyter
    notebooks, along with ToJSON and FromJSON instances
    for conversion to and from JSON .ipynb files.

category:             Text
abi:                  84b5b4e3d9272b79ae255f5f762fd61c
exposed:              True
exposed-modules:      Data.Ipynb
import-dirs:          /usr/lib/ghc-8.10.4/site-local/ipynb-0.1.0.1
library-dirs:         /usr/lib/ghc-8.10.4/site-local/ipynb-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/ipynb-0.1.0.1
hs-libraries:         HSipynb-0.1.0.1-3DGBPS2DK367lmIfmMkRLO
depends:
    aeson-1.5.6.0-I7BbKEwOl3UEL7J6p5LGbn base-4.14.1.0
    base64-bytestring-1.2.0.1-LSGBjcCPG61N7rhXbNth1
    bytestring-0.10.12.0 containers-0.6.2.1 text-1.2.4.1
    unordered-containers-0.2.13.0-3zq6q89i05VC2WIEWnQHAq

haddock-interfaces:   /usr/share/doc/haskell-ipynb/html/ipynb.haddock
haddock-html:         /usr/share/doc/haskell-ipynb/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
